pipe_get_data: Get data

View source: R/aliases.R

pipe_get_dataR Documentation

Get data

Description

Get the data set for the pipeline

Usage

pipe_get_data(pip)

Arguments

pip

Pipeline object

Value

the output defined in the data step, which by default is the first step of the pipeline

Lifecycle

Deprecated. Legacy API. Use pip_new() and related pip_* functions.

Examples

p <- pipe_new("pipe", data = 1:2)
pipe_get_data(p)
pipe_set_data(p, 3:4)
pipe_get_data(p)

pipeflow documentation built on June 15, 2026, 9:10 a.m.