pipe_reset: Reset pipeline

View source: R/aliases.R

pipe_resetR Documentation

Reset pipeline

Description

Resets the pipeline to the state before it was run. This means that all output is removed and the state of all steps is reset to 'New'.

Usage

pipe_reset(pip)

Arguments

pip

Pipeline object

Value

returns the Pipeline object invisibly

Lifecycle

Deprecated. Legacy API. Use pip_new() and related pip_* functions.

Examples

p <- pipe_new("pipe", data = 1:2)
pipe_add(p, "f1", \(x = 1) x)
pipe_add(p, "f2", \(y = 1) y)
pipe_run(p, )
p

pipe_reset(p)
p

pipeflow documentation built on June 15, 2026, 9:10 a.m.