| pipe_set_params_at_step | R Documentation |
Set unbound function parameters defined at given pipeline step where 'unbound' means parameters that are not linked to other steps. If one or more parameters don't exist, an error is given.
pipe_set_params_at_step(pip, step, params)
pip |
|
step |
|
params |
|
returns the Pipeline object invisibly
Deprecated. Legacy API. Use pip_new() and
related pip_* functions.
p <- pipe_new("pipe", data = 1)
pipe_add(p, "add1", \(x = ~data, y = 2, z = 3) x + y)
pipe_set_params_at_step(p, step = "add1", params = list(y = 5, z = 6))
pipe_get_params(p)
try(
pipe_set_params_at_step(p, step = "add1", params = list(foo = 3))
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.