| pip_bind | R Documentation |
Bind two pipelines together by concatenating their steps. If both pipelines have steps with the same name, the step names of the second pipeline will be automatically adapted to avoid name clashes.
pip_bind(x, y)
x |
A pipeflow pipeline object. |
y |
A pipeflow pipeline object. |
A new pipeflow pipeline object representing the bound pipelines.
a <- pip_new("a") |>
pip_add("prep", \(x = 1) x * 2) |>
pip_add("fit", \(x = ~prep) x + 10)
# "prep" exists in both pipelines; the one from b gets a numeric suffix
b <- pip_new("b") |> pip_add("prep", \(x = 5) x * 3)
ab <- pip_bind(a, b)
ab[["step"]] # "prep", "fit", "prep2" (step name conflict auto-resolved)
ab
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.