| pip_data | R Documentation |
This is a convenience wrapper for accessing the internal data.table,
which normally is reachable via p[["pipenv"]][["data"]].
pip_data(x)
x |
A pipeflow pipeline or view. |
The internal data.table is holding the pipeline steps, one row
per step. Unless you know what you are doing, this table should not be
modified directly, as this can corrupt the pipeline including any views
that are derived from it. If you want to experiment, consider cloning the
pipeline first with pip_clone().
The underlying step table as a data.table.
p <- pip_new() |>
pip_add("load", \(n = 5) seq_len(n)) |>
pip_add("model", \(x = ~load) sum(x))
pip_data(p)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.