| pip_run | R Documentation |
Executes all pending steps in order. Steps already in state "done" are
skipped unless force = TRUE.
pip_run(
x,
lgr = pipeflow_lgr,
force = FALSE,
progress = NULL,
recursive = FALSE
)
x |
A pipeflow pip or view |
lgr |
A logging function of the form |
force |
Logical indicating if all steps should be forced to run, regardless of whether they are outdated or not. |
progress |
Optional callback of the form
|
recursive |
If |
When x is a view, requested rows are run together with required
upstream dependencies.
The updated pipeline or view, invisibly.
vignette("v06-self-modify-pipeline", package = "pipeflow")
for an advanced example of recursive/dynamic pipelines.
p <- pip_new() |>
pip_add("load", \(n = 3) seq_len(n)) |>
pip_add("square", \(x = ~load) x^2) |>
pip_add("total", \(x = ~square) sum(x))
pip_run(p)
p
# Already-done steps are skipped on a second run
pip_run(p) # all steps skipped
# lgr = NULL suppresses log output
pip_run(p, lgr = NULL)
# force = TRUE re-executes every step regardless of state
pip_run(p, force = TRUE)
# Run only a subset of steps via a view;
# upstream dependencies are automatically included
v <- pip_view(p, i = "total")
pip_run(v)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.