| pip_set_params | R Documentation |
Updates the default values of tunable parameters across the pipeline. Affected steps and their downstream dependents are automatically marked as outdated.
pip_set_params(p, params = list())
p |
A pipeflow pip or view |
params |
Named list of parameters to set. |
Parameters of locked steps are never changed and their state remains unchanged.
The updated pipeline or view, invisibly.
p <- pip_new() |>
pip_add("load", \(n = 10) seq_len(n)) |>
pip_add("scale", \(x = ~load, factor = 0.5) x * factor)
# See all adjustable parameters before running
pip_get_params(p) # list(n = 10, factor = 0.5)
# Updating params marks affected steps (and their dependents) outdated
pip_set_params(p, params = list(n = 5, factor = 2.0))
p
pip_run(p)
p
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.