| pip_tag | R Documentation |
Adds tags to existing tags for all steps in the pipeline unless p is a
view, in which case tags are only added for steps covered by the view.
Locked steps are skipped and not updated.
pip_tag(p, tags = character())
p |
A pipeflow pip or view. |
tags |
Character vector of tags to add for each selected step. |
The updated pipeline or view, invisibly.
p <- pip_new() |>
pip_add("load", \(x = 1) x) |>
pip_add("fit", \(x = ~load) x + 1)
# Tag every step in the pipeline at once
pip_tag(p, tags = c("daily", "core"))
p[["pipeline"]][["tags"]] # both steps have c("daily", "core")
# Add an extra tag to only one step via a view
v <- pip_view(p, i = "fit")
pip_tag(v, tags = "model")
p[["pipeline"]][["tags"]] # "fit" also has "model"
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.