| pip_unlock | R Documentation |
Unlocks all selected steps in the pipeline unless p is a view, in which
case only steps covered by the view are unlocked.
pip_unlock(p)
p |
A pipeflow pip or view. |
The updated pipeline or view, invisibly.
p <- pip_new() |>
pip_add("load", \(x = 1) x) |>
pip_add("fit", \(x = ~load) x * 2)
# Lock all steps, then unlock to restore normal execution
pip_lock(p)
p[["pipeline"]][["locked"]] # TRUE, TRUE
pip_unlock(p)
p[["pipeline"]][["locked"]] # FALSE, FALSE
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.