| print.pipeflow_pip | R Documentation |
Print pipeflow objects
## S3 method for class 'pipeflow_pip'
print(
x,
rows = integer(),
cols = getOption("pipeflow.print.cols", default = "core"),
topn = getOption("pipeflow.print.topn", default = 5),
nrows = getOption("pipeflow.print.nrows", default = 50),
row.names = getOption("pipeflow.print.rownames", default = TRUE),
class = getOption("pipeflow.print.class", default = FALSE),
header = TRUE,
...
)
## S3 method for class 'pipeflow_view'
print(x, header = TRUE, ...)
x |
A pipeflow pipeline or view. |
rows |
Row indices to be printed. If empty, all rows are printed. |
cols |
The columns to be printed. Can be either one of
|
topn |
The number of rows to be printed from the beginning
and end of tables with more than |
nrows |
The number of rows printed before truncation is enforced. |
row.names |
If TRUE, row indices will be printed alongside x. |
class |
If TRUE, the resulting output will include above each column its storage class (or a self-evident abbreviation thereof). |
header |
If TRUE, a header with the pipeline name and number of steps will be printed. |
... |
Other arguments passed to |
Invisibly returns x.
p <- pip_new("demo") |>
pip_add("load", \(n = 5) seq_len(n), tags = c("io", "raw")) |>
pip_add("square", \(x = ~load) x^2, tags = "compute") |>
pip_add("total", \(x = ~square) sum(x), tags = "compute")
print(p) # core columns: step, depends, tags, out, state
print(p, cols = "all") # all non-hidden columns
print(p, rows = 2:3) # print only steps 2 and 3
p <- pip_new() |>
pip_add("s1", \(x = 1) x, tags = "io") |>
pip_add("s2", \(x = ~s1) x + 1, tags = "model")
# A view header shows how many steps are selected out of the total
v <- pip_view(p, tags = "model")
print(v) # "<pipeflow_view> pipe view (1 of 2 steps)"
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.